import { type ObservableInput, Observable } from 'rxjs';
/**
 * Like {@link combineLatest}, except that it does not wait for all Observables to emit before emitting an initial
 * value. It emits whenever any of the source Observables emit.
 *
 * If {@link defaultValue} is provided, it will be used to represent any source Observables
 * that have not yet emitted in the emitted array. If it is not provided, source Observables
 * that have not yet emitted will not be represented in the emitted array.
 *
 * Also unlike {@link combineLatest}, if the source Observables array is empty, it emits an empty array and
 * completes.
 *
 * This behavior is useful for the common pattern of combining providers: we don't want to block on the slowest
 * provider for the initial emission, and an empty array of providers should yield an empty array (instead of
 * yielding an Observable that never completes).
 *
 * @see {@link combineLatest}
 *
 * @todo Consider renaming this to combineProviders and making it also catchError from each Observable (and return
 * the error as a value).
 *
 * @param observables The source Observables.
 * @param defaultValue The value to emit for a source Observable if it has not yet emitted a value by the time
 * another Observable has emitted a value.
 * @returns An Observable of an array of the most recent values from each input Observable (or
 * {@link defaultValue}).
 */
export declare function combineLatestOrDefault<T>(observables: ObservableInput<T>[], defaultValue?: T): Observable<T[]>;
